@@ -1,7 +1,7 @@
 /* tatypes.h */
 
 /*
- * Copyright (C) 2011-2017 by Werner Lemberg.
+ * Copyright (C) 2011-2019 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -117,8 +117,8 @@ extern void* _ta_debug_hints;
 typedef struct TA_WidthRec_
 {
   FT_Pos org; /* original position/width in font units */
-  FT_Pos cur; /* current/scaled position/width in device sub-pixels */
-  FT_Pos fit; /* current/fitted position/width in device sub-pixels */
+  FT_Pos cur; /* current/scaled position/width in device subpixels */
+  FT_Pos fit; /* current/fitted position/width in device subpixels */
 } TA_WidthRec, *TA_Width;
 
 
